==> esp8266-0.3.0.crate: esp8266-0.3.0/src/dport/dport_ctl.rs <==
#[doc = "Register `DPORT_CTL` reader"]
pub struct R(crate::R<DPORT_CTL_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<DPORT_CTL_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<DPORT_CTL_SPEC>> for R {
    fn from(reader: crate::R<DPORT_CTL_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `DPORT_CTL` writer"]
pub struct W(crate::W<DPORT_CTL_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<DPORT_CTL_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl core::convert::From<crate::W<DPORT_CTL_SPEC>> for W {
    fn from(writer: crate::W<DPORT_CTL_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `DPORT_CTL_DOUBLE_CLK` reader - "]
pub struct DPORT_CTL_DOUBLE_CLK_R(crate::FieldReader<bool, bool>);
impl DPORT_CTL_DOUBLE_CLK_R {
    pub(crate) fn new(bits: bool) -> Self {
        DPORT_CTL_DOUBLE_CLK_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for DPORT_CTL_DOUBLE_CLK_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `DPORT_CTL_DOUBLE_CLK` writer - "]
pub struct DPORT_CTL_DOUBLE_CLK_W<'a> {
    w: &'a mut W,
}
impl<'a> DPORT_CTL_DOUBLE_CLK_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x01) | ((value as u32) & 0x01);
        self.w
    }
}
impl R {
    #[doc = "Bit 0"]
    #[inline(always)]
    pub fn dport_ctl_double_clk(&self) -> DPORT_CTL_DOUBLE_CLK_R {
        DPORT_CTL_DOUBLE_CLK_R::new((self.bits & 0x01) != 0)
    }
}
impl W {
    #[doc = "Bit 0"]
    #[inline(always)]
    pub fn dport_ctl_double_clk(&mut self) -> DPORT_CTL_DOUBLE_CLK_W {
        DPORT_CTL_DOUBLE_CLK_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "DPORT_CTL\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dport_ctl](index.html) module"]
pub struct DPORT_CTL_SPEC;
impl crate::RegisterSpec for DPORT_CTL_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [dport_ctl::R](R) reader structure"]
impl crate::Readable for DPORT_CTL_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [dport_ctl::W](W) writer structure"]
impl crate::Writable for DPORT_CTL_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets DPORT_CTL to value 0"]
impl crate::Resettable for DPORT_CTL_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp8266-0.4.0.crate: esp8266-0.4.0/src/dport/dport_ctl.rs <==
#[doc = "Register `DPORT_CTL` reader"]
pub struct R(crate::R<DPORT_CTL_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<DPORT_CTL_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<DPORT_CTL_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<DPORT_CTL_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `DPORT_CTL` writer"]
pub struct W(crate::W<DPORT_CTL_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<DPORT_CTL_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<DPORT_CTL_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<DPORT_CTL_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `DPORT_CTL_DOUBLE_CLK` reader - "]
pub struct DPORT_CTL_DOUBLE_CLK_R(crate::FieldReader<bool, bool>);
impl DPORT_CTL_DOUBLE_CLK_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        DPORT_CTL_DOUBLE_CLK_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for DPORT_CTL_DOUBLE_CLK_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `DPORT_CTL_DOUBLE_CLK` writer - "]
pub struct DPORT_CTL_DOUBLE_CLK_W<'a> {
    w: &'a mut W,
}
impl<'a> DPORT_CTL_DOUBLE_CLK_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
        self.w
    }
}
impl R {
    #[doc = "Bit 0"]
    #[inline(always)]
    pub fn dport_ctl_double_clk(&self) -> DPORT_CTL_DOUBLE_CLK_R {
        DPORT_CTL_DOUBLE_CLK_R::new((self.bits & 0x01) != 0)
    }
}
impl W {
    #[doc = "Bit 0"]
    #[inline(always)]
    pub fn dport_ctl_double_clk(&mut self) -> DPORT_CTL_DOUBLE_CLK_W {
        DPORT_CTL_DOUBLE_CLK_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "DPORT_CTL\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dport_ctl](index.html) module"]
pub struct DPORT_CTL_SPEC;
impl crate::RegisterSpec for DPORT_CTL_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [dport_ctl::R](R) reader structure"]
impl crate::Readable for DPORT_CTL_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [dport_ctl::W](W) writer structure"]
impl crate::Writable for DPORT_CTL_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets DPORT_CTL to value 0"]
impl crate::Resettable for DPORT_CTL_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
